@@ -21,12 +21,15 @@ class ScriptLibInfo
 												'1.8'	=> 'jquery-1.8.3.min.js',
 												'1.9'	=> 'jquery-1.9.1.min.js',
 												'1.10'	=> 'jquery-1.10.2.min.js',
-												'1.11'	=> 'jquery-1.11.0.min.js',
+												'1.11'	=> 'jquery-1.11.1.min.js',
 												'2.0'	=> 'jquery-2.0.3.min.js',
-												'2.1'	=> 'jquery-2.1.0.min.js');
+												'2.1'	=> 'jquery-2.1.1.min.js');
 	private static $wysiwygEditorType = 'fckeditor';		// WYSIWYGエディタータイプ
 	
-	// Javascriptライブラリ(DBでの設定値)
+	// ##### Javascriptライブラリ(DBでの設定値) #####
+	// ライブラリセット(複数ライブラリの構成)
+	const LIB_SET_CKEDITOR_M3_TOOLBAR	= 'ckeditor_m3toolbar';		// CKEditorのツールバー用ライブラリ
+	
 	// ベースライブラリ
 	const LIB_JQUERY				= 'jquery';
 	const LIB_JQUERY_UI				= 'jquery-ui';
@@ -234,7 +237,6 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.8/jquery.jqplot.min.css';
 //	const JQUERY_UI_CORE_FILENAME	= 'jquery-ui-core-1.10.1.min.js';			// JQuery UI Core (Core,Interactions)
 	const JQUERY_UI_CORE_FILENAME	= 'jquery-ui-core-1.9.2.min.js';			// JQuery UI Core (Core,Interactions)
 	const FCKEDITOR_FILENAME		= 'fckeditor2.6.6/fckeditor.js';			// FCKEditor
-//	const CKEDITOR_FILENAME			= 'ckeditor4.2.0/ckeditor.js';				// CKEditor
 	const CKEDITOR_FILENAME			= 'ckeditor4.3.3/ckeditor.js';				// CKEditor
 	const ELFINDER_FILENAME			= 'elfinder-2.0/js/elfinder.min.js';		// elFinder
 	const ELFINDER_LANG_FILENAME	= 'elfinder-2.0/js/i18n/elfinder.ja.js';	// elFinder言語ファイル
@@ -520,6 +522,22 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.8/jquery.jqplot.min.css';
 		
 		return $dependentLib[$lib];
 	}
+	/**
+	 * ライブラリセットの構成ライブラリ取得
+	 *
+	 * @param $string $libSetId		ライブラリセットID
+	 * @return array				ライブラリ
+	 */
+	static function getLibSet($libSetId)
+	{
+		static $libSet = array(	self::LIB_SET_CKEDITOR_M3_TOOLBAR	=>	array(self::LIB_ELFINDER));		// CKEditorのMagic3拡張ツールバー用
+		$libs = $libSet[$libSetId];
+		if (isset($libs)){
+			return $libs;
+		} else {
+			return array();
+		}
+	}
 	/**
 	 * jQuery UIライブラリ情報取得
 	 *
