@@ -2,10 +2,10 @@
  * jqPlot
  * Pure JavaScript plotting plugin using jQuery
  *
- * Version: 1.0.7
- * Revision: 1224
+ * Version: 1.0.4
+ * Revision: 1120
  *
- * Copyright (c) 2009-2013 Chris Leonello
+ * Copyright (c) 2009-2012 Chris Leonello
  * jqPlot is currently available for use in all personal or commercial projects 
  * under both the MIT (http://www.opensource.org/licenses/mit-license.php) and GPL 
  * version 2.0 (http://www.gnu.org/licenses/gpl-2.0.html) licenses. This means that you can 
@@ -115,7 +115,7 @@
         
         //////
         // This is probably wrong here.
-        // After going back and forth on whether renderer should be the thing
+        // After going back and forth on wether renderer should be the thing
         // or extend the thing, it seems that it it best if it is a property
         // on the thing.  This should be something that is commonized 
         // among series renderers in the future.
@@ -198,20 +198,14 @@
             var count = 0;
             for (var i=skip; i<l; i+=skip) {
                 this.data.splice(i+count, 0, [null, null]);
-                this._plotData.splice(i+count, 0, [null, null]);
-                this._stackData.splice(i+count, 0, [null, null]);
                 count++;
             }
             for (i=0; i<this.data.length; i++) {
                 if (this._primaryAxis == '_xaxis') {
                     this.data[i][0] = i+1;
-                    this._plotData[i][0] = i+1;
-                    this._stackData[i][0] = i+1;
                 }
                 else {
                     this.data[i][1] = i+1;
-                    this._plotData[i][1] = i+1;
-                    this._stackData[i][1] = i+1;
                 }
             }
         }
@@ -513,7 +507,7 @@
                             xstart = 0;
                         }
                     }
-                    if ((this.fillToZero && this._plotData[i][0] < 0) || (this.waterfall && this._data[i][0] < 0)) {
+                    if ((this.fillToZero && this._plotData[i][1] < 0) || (this.waterfall && this._data[i][1] < 0)) {
                         if (this.varyBarColor && !this._stack) {
                             if (this.useNegativeColors) {
                                 opts.fillStyle = negativeColors.next();
@@ -522,9 +516,6 @@
                                 opts.fillStyle = positiveColors.next();
                             }
                         }
-                        else {
-                            opts.fillStyle = negativeColor;
-                        }
                     }
                     else {
                         if (this.varyBarColor && !this._stack) {
@@ -797,4 +788,4 @@
     }
     
     
-})(jQuery);
\ No newline at end of file
+})(jQuery);    
\ No newline at end of file
