@@ -127,6 +127,33 @@ function m3ShowPreviewWindow(type, url)
 	}
 	window.open(url, "", "toolbar=no,menubar=no,location=no,status=no,scrollbars=yes,resizable=yes,width=" + width + ",height=" + height);
 }
+// 処理中ダイアログ表示
+function m3ShowProcessModal()
+{
+	// 画面上のフォーカスを外す
+	$('input,textarea,select').blur();
+	
+	$('#processing-modal').modal('show');
+}
+// 処理中ダイアログ順部
+function m3PrepareProcessModal()
+{
+	if ($('#processing-modal').size() == 0){		// ダイアログが存在しない場合
+		var modal  = '<div class="modal modal-processing fade" id="processing-modal" role="dialog" aria-hidden="true">';
+			modal += '<div class="modal-dialog">';
+			modal += '<div class="modal-content">';
+			modal += '<div class="modal-body">';
+			modal += '<div class="text-center">';
+			modal += '<img src="' + M3_ROOT_URL + '/images/system/processing.gif" class="icon" />';
+			modal += '<h4>処理中</h4>';
+			modal += '</div>';
+			modal += '</div>';
+			modal += '</div>';
+			modal += '</div>';
+			modal += '</div>';
+		$("body").append(modal);
+	}
+}
 /**
  * 画像ファイルブラウザを表示
  *
@@ -270,13 +297,16 @@ function m3_setHtmlEditor(id, isMobile)
  */
 function m3SetWysiwygEditor(id, height, toolbarVisible, barType)
 {
+	// アクセスポイントの設定
+	_m3SetAccessPoint(M3_CONFIG_WIDGET_DEVICE_TYPE);
+		
 	if (M3_WYSIWYG_EDITOR == 'ckeditor'){
 		var config = {};
-		if (M3_USE_GOOGLEMAPS){
+//		if (M3_USE_GOOGLEMAPS){
 			config['customConfig'] = M3_ROOT_URL + '/scripts/m3/ckconfig.js';
-		} else {
-			config['customConfig'] = M3_ROOT_URL + '/scripts/m3/ckconfig_intranet.js';
-		}
+//		} else {
+//			config['customConfig'] = M3_ROOT_URL + '/scripts/m3/ckconfig_intranet.js';
+//		}
 		if (height) config['height'] = height;
 		if (toolbarVisible != null && !toolbarVisible) config['toolbarStartupExpanded'] = false;
 		if (barType){
@@ -348,14 +378,38 @@ function m3LoadCKTools()
 	dummyCKParent = $('#_dummy_ck_parent');
 
 	var config = {};
-	config['customConfig'] = M3_ROOT_URL + '/scripts/m3/ckconfig_direct.js';
-//	config['toolbar'] = 'Full';
+//	config['customConfig'] = M3_ROOT_URL + '/scripts/m3/ckconfig_direct.js';
+	config['customConfig'] = M3_ROOT_URL + '/scripts/m3/ckconfig.js';
+	config['extraPlugins'] = 'linkinfo';
 	CKEDITOR.replace('_dummy_ckeditor', config);
 	dummyCKParent.hide();
 }
+/**
+ * URL作成用のアクセスポイントを設定
+ *
+ * @param int deviceType				デバイスタイプ(0=PC,1=携帯,2=スマートフォン)
+ * @return なし
+ */
+function _m3SetAccessPoint(deviceType)
+{
+	// アクセスポイント(空=PC,m=携帯,s=スマートフォン)取得
+	var accessPoint;
+	switch (deviceType){
+		case 0:		// PC用
+		default:
+			accessPoint = '';
+			break;
+		case 1:		// 携帯用
+			accessPoint = 'm';
+			break;
+		case 2:		// スマートフォン用
+			accessPoint = 's';
+			break;
+	}
+	_m3AccessPoint = accessPoint;
+}
 /**
  * リンク用のURLを作成
- * あらかじめを実行しておく。
  *
  * @param int deviceType				デバイスタイプ(0=PC,1=携帯,2=スマートフォン)
  * @param string url					URL初期値
