@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m_googlemapsWidgetContainer.php 3877 2010-12-03 08:26:41Z fishbone $
+ * @version    SVN: $Id: m_googlemapsWidgetContainer.php 4770 2012-03-19 12:15:19Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -84,11 +84,6 @@ class m_googlemapsWidgetContainer extends BaseWidgetContainer
 		$pixelX = 0;		// 経度移動ピクセル値
 		$pixelY = 0;		// 緯度移動ピクセル値
 		
-		// 共通データ取得
-		$paramObj = $this->getWidgetParamObj();
-		if (!empty($paramObj)){
-			$key	= $paramObj->key;		// Googleマップ利用キー
-		}
 		// URLからパラメータを取得
 		$value	= $request->trimValueOf('center');		// 中心点
 		if (!empty($value)){
@@ -124,7 +119,7 @@ class m_googlemapsWidgetContainer extends BaseWidgetContainer
 		if ($pixelX != 0 || $pixelY != 0) list($lng, $lat) = $this->moveByPixel($lng, $lat, $pixelX, $pixelY, $zoom);
 
 		// 画像URL作成
-		$url = 'http://maps.google.com/staticmap?center=' . $lat . ',' . $lng . '&zoom=' . $zoom . '&size=' . $width . 'x' . $height . '&key=' . $key;
+		$url = 'http://maps.google.com/maps/api/staticmap?center=' . $lat . ',' . $lng . '&zoom=' . $zoom . '&size=' . $width . 'x' . $height . '&format=gif&mobile=true&sensor=true';	// docomo携帯では「format」が必須
 		if ($showMarker){// マーカー表示
 			$url .= '&markers=' . $markerLat . ',' . $markerLng;
 		}
@@ -151,7 +146,7 @@ class m_googlemapsWidgetContainer extends BaseWidgetContainer
 		$downUrlLink = $this->convertUrlToHtmlEntity($this->getUrl($this->gEnv->createCurrentPageUrlForMobile($param)));
 
 		// 表示データ埋め込み
-		$this->tmpl->addVar("_widget", "url",	$url);
+		$this->tmpl->addVar("_widget", "url",		$this->getUrl($url));
 		$this->tmpl->addVar("_widget", "option",	$option);
 		$this->tmpl->addVar("_widget", "url_small",	$smallUrlLink);
 		$this->tmpl->addVar("_widget", "url_large",	$largeUrlLink);
